:mod:`ecc` --- ECDSA implementation supporting secp256r1
========================================================

This is a native C implementation with wrappers for Python. It supports the SECP256R1 curve as used by NEO
This is pure python implementation of ECDSA with secp256r1 curve support as used by NEO.


.. autoclass:: neo3.core.cryptography.ecc.ECCCurve
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: neo3.core.cryptography.ecc.ECPoint
   :members:
   :undoc-members:
   :show-inheritance:
